Structs
- Extract
Version - This is a custom extractor for Axum that extracts the version, via the
X-Versionrequest header. If theX-Versionheader is present, it returns it. If theX-Versionheader is not present, it defaults tolatest.
X-Version request header.
If the X-Version header is present, it returns it.
If the X-Version header is not present, it defaults to latest.